==> jhipster-core-6.0.2.tgz: package/lib/core/validated_jdl_options.js <==
/**
 * Copyright 2013-2019 the original author or authors from the JHipster project.
 *
 * This file is part of the JHipster project, see http://www.jhipster.tech/
 * for more information.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

const UnaryOptionValidator = require('../exceptions/unary_option_validator');
const BinaryOptionValidator = require('../exceptions/binary_option_validator');
const JDLOptions = require('./jdl_options');

class ValidatedJDLOptions extends JDLOptions {
  constructor() {
    super();
    this.unaryOptionValidator = new UnaryOptionValidator();
    this.binaryOptionValidator = new BinaryOptionValidator();
  }

  addOption(option) {
    if (!option || !option.getType) {
      throw new Error("Can't add nil option.");
    }
    if (option.getType() === 'UNARY') {
      this.unaryOptionValidator.validate(option);
    } else {
      this.binaryOptionValidator.validate(option);
    }
    super.addOption(option);
  }
}

module.exports = ValidatedJDLOptions;

==> jhipster-core-7.3.4.tgz: package/lib/core/validated_jdl_options.js <==
/**
 * Copyright 2013-2020 the original author or authors from the JHipster project.
 *
 * This file is part of the JHipster project, see http://www.jhipster.tech/
 * for more information.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

const UnaryOptionValidator = require('../validators/unary_option_validator');
const BinaryOptionValidator = require('../validators/binary_option_validator');
const JDLOptions = require('./jdl_options');

class ValidatedJDLOptions extends JDLOptions {
  constructor() {
    super();
    this.unaryOptionValidator = new UnaryOptionValidator();
    this.binaryOptionValidator = new BinaryOptionValidator();
  }

  addOption(option) {
    if (!option || !option.getType) {
      throw new Error("Can't add nil option.");
    }
    if (option.getType() === 'UNARY') {
      this.unaryOptionValidator.validate(option);
    } else {
      this.binaryOptionValidator.validate(option);
    }
    super.addOption(option);
  }
}

module.exports = ValidatedJDLOptions;
